@@ -3,15 +3,16 @@ Main interface for signer service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.signer import (
+    from mypy_boto3_signer import (
         Client,
         ListSigningJobsPaginator,
         ListSigningPlatformsPaginator,
         ListSigningProfilesPaginator,
         SignerClient,
         SuccessfulSigningJobWaiter,
-        )
+    )
 
     session = boto3.Session()
 
@@ -23,8 +24,9 @@ Usage::
     list_signing_jobs_paginator: ListSigningJobsPaginator = client.get_paginator("list_signing_jobs")
     list_signing_platforms_paginator: ListSigningPlatformsPaginator = client.get_paginator("list_signing_platforms")
     list_signing_profiles_paginator: ListSigningProfilesPaginator = client.get_paginator("list_signing_profiles")
+    ```
 """
-from mypy_boto3_signer.client import SignerClient as Client, SignerClient
+from mypy_boto3_signer.client import SignerClient
 from mypy_boto3_signer.paginator import (
     ListSigningJobsPaginator,
     ListSigningPlatformsPaginator,
@@ -32,6 +34,8 @@ from mypy_boto3_signer.paginator import (
 )
 from mypy_boto3_signer.waiter import SuccessfulSigningJobWaiter
 
+Client = SignerClient
+
 
 __all__ = (
     "Client",
